==> order-center-api-2.0.9-CLOUD-UAT-20220622.102922-24-sources.jar: com/tydic/dyc/oc/service/order/bo/UocGetOrderAllDetailServiceRspItemBo.java <==
package com.tydic.dyc.oc.service.order.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/14 13:44
 */
@Data
public class UocGetOrderAllDetailServiceRspItemBo implements Serializable {

    private static final long serialVersionUID = 2926981820995772999L;

    @DocField("订单详情扩展")
    private List<UocGetOrderAllDetailServiceRspItemExtBo> itemExtBos;

    @DocField("订单详情延保信息")
    private List<UocGetOrderAllDetailServiceRspItemEwBo> itemEwBos;

    @DocField(value = "订单明细id")
    private Long orderItemId;

    @DocField(value = "订单id")
    private Long orderId;

    @DocField(value = "明细类型             1 商品sku             2 物资             3 项目")
    private Integer itemType;

    @DocField(value = "明细状态")
    private String orderItemState;

    @DocField(value = "单品ID")
    private String skuId;

    @DocField(value = "供应商ID")
    private String supplierId;

    @DocField(value = "店铺ID")
    private String supplierShopId;

    @DocField(value = "采购金额")
    private BigDecimal purchasePrice;

    @DocField(value = "采购金额")
    private BigDecimal salePrice;

    @DocField(value = "采购数量")
    private BigDecimal purchaseCount;

    @DocField(value = "运费")
    private BigDecimal transFee;

    @DocField(value = "应付金额")
    private BigDecimal payFee;

    @DocField(value = "积分优惠金额")
    private BigDecimal integralDisFee;

    @DocField(value = "活动优惠金额")
    private BigDecimal actDisFee;

    @DocField(value = "其它优惠金额")
    private BigDecimal otherDisFee;

    @DocField(value = "实付金额")
    private BigDecimal usedFee;

    @DocField(value = "实付积分")
    private BigDecimal usedIntegral;

    @DocField(value = "币种")
    private String currencyType;

    @DocField(value = "税金")
    private String taxPrice;

    @DocField(value = "税率")
    private String tax;

    @DocField(value = "预计发货时间")
    private Date preSendTime;

    @DocField(value = "预计交货时间")
    private Date preOfferTime;

    @DocField(value = "计量单位")
    private String unitName;

    @DocField(value = "结算计量单位")
    private String settleUnit;

    @DocField(value = "外部电商主订单id")
    private String imOrderId;

    @DocField(value = "外部电商子订单id")
    private String imSubOrderId;

    @DocField(value = "到货周期")
    private String arrivalTime;

    @DocField(value = "加价率")
    private Double markUpRate;

    @DocField(value = "商品服务费 ")
    private String serPrice;

    @DocField(value = "计划编号")
    private String planNo;

    @DocField(value = "计划明细编号")
    private String planItemNo;

    @DocField(value = "超验百分比，下单时保存（协议、无协议）")
    private Integer inspectionExcessPercent;

    @DocField(value = "税务编码")
    private String taxId;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "备注")
    private String remark;

    @DocField(value = "扩展字段")
    private String extField1;

    @DocField(value = "扩展字段")
    private String extField2;

    @DocField(value = "扩展字段")
    private String extField3;

    @DocField(value = "扩展字段")
    private String extField4;

    @DocField(value = "扩展字段")
    private String extField5;

    

}

==> order-center-api-3.2.2-CLOUD-UAT-20250918.070708-19-sources.jar: com/tydic/dyc/oc/service/order/bo/UocGetOrderAllDetailServiceRspItemBo.java <==
package com.tydic.dyc.oc.service.order.bo;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：
 *
 * @author tgy
 * @date 2022/2/14 13:44
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetOrderAllDetailServiceRspItemBo implements Serializable {

    private static final long serialVersionUID = 2926981820995772999L;

    //订单详情扩展//
    private List<UocGetOrderAllDetailServiceRspItemExtBo> itemExtBos;

    //订单详情延保信息//
    private List<UocGetOrderAllDetailServiceRspItemEwBo> itemEwBos;

    //订单明细id//
    private Long orderItemId;

    //订单id//
    private Long orderId;

    //明细类型             1 商品sku             2 物资             3 项目//
    private Integer itemType;

    //明细状态//
    private String orderItemState;

    //单品ID//
    private String skuId;

    //供应商ID//
    private String supplierId;

    //店铺ID//
    private String supplierShopId;

    //采购金额//
    private BigDecimal purchasePrice;

    //采购金额//
    private BigDecimal salePrice;

    //采购数量//
    private BigDecimal purchaseCount;

    //运费//
    private BigDecimal transFee;

    //应付金额//
    private BigDecimal payFee;

    //积分优惠金额//
    private BigDecimal integralDisFee;

    //活动优惠金额//
    private BigDecimal actDisFee;

    //其它优惠金额//
    private BigDecimal otherDisFee;

    //实付金额//
    private BigDecimal usedFee;

    //实付积分//
    private BigDecimal usedIntegral;

    //币种//
    private String currencyType;

    //税金//
    private String taxPrice;

    //税率//
    private String tax;

    //预计发货时间//
    private Date preSendTime;

    //预计交货时间//
    private Date preOfferTime;

    //计量单位//
    private String unitName;

    //结算计量单位//
    private String settleUnit;

    //外部电商主订单id//
    private String imOrderId;

    //外部电商子订单id//
    private String imSubOrderId;

    //到货周期//
    private String arrivalTime;

    //加价率//
    private Double markUpRate;

    //商品服务费 //
    private String serPrice;

    //计划编号//
    private String planNo;

    //计划明细编号//
    private String planItemNo;

    //超验百分比，下单时保存（协议、无协议）//
    private Integer inspectionExcessPercent;

    //税务编码//
    private String taxId;

    //创建时间//
    private Date createTime;

    //创建工号//
    private String createOperId;

    //更新时间//
    private Date updateTime;

    //更新工号//
    private String updateOperId;

    //备注//
    private String remark;

    //扩展字段//
    private String extField1;

    //扩展字段//
    private String extField2;

    //扩展字段//
    private String extField3;

    //扩展字段//
    private String extField4;

    //扩展字段//
    private String extField5;

    

}
